@@ -68,3 +68,44 @@ pub struct SqlStatementMap{
     pub statement: String,
     pub clause_map: HashMap<String, String>,
 }
+
+pub enum DB {
+    Oracle(String),
+    Posgresql(String),
+}
+#[derive(Debug)]
+pub enum DbConnStatus {
+    Idle,
+    Active,
+    Disconnected,
+}
+#[derive(Debug)]
+pub enum Value {
+    String(String),
+    StringLikeLeft(String),
+    StringLikeRight(String),
+    StringLikeBoth(String),
+    Float(f64),
+    Integer(i64),
+    Bool(bool),
+    Date(String),
+    StringArray(Vec<String>),
+    IntegerArray(Vec<i64>),
+    BareString(String),
+}
+
+pub enum ColumnType {
+    String,
+    Float,
+    Integer,
+    Date,
+}
+pub struct Column {
+    pub name: String,
+    pub column_type: ColumnType,
+}
+pub struct SqlParam<'a> {
+    pub sql_id: &'a str,
+    pub sub_sql_id: &'a str,
+    pub param: &'a HashMap<String, Value>,
+}
\ No newline at end of file
